"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const graphql_config_1 = require("graphql-config");
const load_from_code_file_1 = require("./load-from-code-file");
const load_from_gql_file_1 = require("./load-from-gql-file");
const load_from_json_file_1 = require("./load-from-json-file");
const load_from_url_1 = require("./load-from-url");
function createLoader(condition, loaderFn) {
    return async (pointer, options) => {
        if (typeof pointer === 'string' && condition.test(pointer)) {
            const document = await loaderFn(pointer, options);
            return new graphql_config_1.Source({
                document,
                location: pointer,
            });
        }
        return undefined;
    };
}
const R_IS_CODE = /\.(t|j)sx?$/i;
const R_IS_GRAPHQL = /\.g(raph)?qls?$/i;
const R_IS_JSON = /\.json$/i;
const R_IS_URL = /^https?:/i;
exports.CodeFileLoader = createLoader(R_IS_CODE, load_from_code_file_1.loadFromCodeFile);
exports.GraphQLFileLoader = createLoader(R_IS_GRAPHQL, load_from_gql_file_1.loadFromGqlFile);
exports.JSONFileLoader = createLoader(R_IS_JSON, load_from_json_file_1.loadFromJsonFile);
exports.UrlLoader = createLoader(R_IS_URL, load_from_url_1.loadFromUrl);
//# sourceMappingURL=graphql-config.js.map