import { Source } from 'graphql-config';
import { loadFromCodeFile } from './load-from-code-file';
import { loadFromGqlFile } from './load-from-gql-file';
import { loadFromJsonFile } from './load-from-json-file';
import { loadFromUrl } from './load-from-url';
function createLoader(condition, loaderFn) {
    return async (pointer, options) => {
        if (typeof pointer === 'string' && condition.test(pointer)) {
            const document = await loaderFn(pointer, options);
            return new Source({
                document,
                location: pointer,
            });
        }
        return undefined;
    };
}
const R_IS_CODE = /\.(t|j)sx?$/i;
const R_IS_GRAPHQL = /\.g(raph)?qls?$/i;
const R_IS_JSON = /\.json$/i;
const R_IS_URL = /^https?:/i;
export const CodeFileLoader = createLoader(R_IS_CODE, loadFromCodeFile);
export const GraphQLFileLoader = createLoader(R_IS_GRAPHQL, loadFromGqlFile);
export const JSONFileLoader = createLoader(R_IS_JSON, loadFromJsonFile);
export const UrlLoader = createLoader(R_IS_URL, loadFromUrl);
//# sourceMappingURL=graphql-config.js.map